from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class McgdCls:
	"""Mcgd commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mcgd", core, parent)

	def set(self) -> None:
		"""SCPI: CONFigure:SETTings:MCGD \n
		Snippet: driver.applications.k17Mcgd.configure.settings.mcgd.set() \n
		Queries all currently defined generator setup settings on the connected signal generator and applies the settings to the
		R&S FSW. \n
		"""
		self._core.io.write(f'CONFigure:SETTings:MCGD')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: CONFigure:SETTings:MCGD \n
		Snippet: driver.applications.k17Mcgd.configure.settings.mcgd.set_with_opc() \n
		Queries all currently defined generator setup settings on the connected signal generator and applies the settings to the
		R&S FSW. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'CONFigure:SETTings:MCGD', opc_timeout_ms)
